""" run HRI components using client_info[*.json]
"""
import sys, json
import re
# import asyncio
import subprocess
import time

def get_comp(id):
    return id.split(':')[6]

def get_port(url):
    pat = re.compile('http://([^/:]+):(\d+)')
    m = pat.search(url)
    if m is not None:
        return m.group(2)
    else:
        print('invalid url', url)
        sys.exit(1)

def get_robot(id):
    return id.split(':')[5]

def setup_comp(fn):
    # open client_info
    with open(fn,'r') as f:
        d=json.load(f)
        # print(d)

    tab = { 'PersonLocalization':'Person_Localization.py',
            'SystemInformation':'System_Information.py',
            'SpeechRecognition':'Dummy_Speech_Recognition.py',
            'Navigation':'Navigation.py'
    }

    # generate commands for HRI Components
    l=[ ["rosrun", "route_guidance_ros", tab[get_comp(k)], get_port(v['url']), get_robot(k)]
        for k, v in d.items() if 'HRIComponent' in k
    ]

    # run commands
    try:
        p=[subprocess.Popen(x) for x in l]
        while True:
            # wait forever
            print('sleeping')
            time.sleep(60)
    except KeyboardInterrupt:
        # kill all child processes
        for x in p:
            if x.returncode is None:
                print('kill')
                x.kill()
            
    print('finished')

def main():

    if len(sys.argv) < 2:
        print("usage: python3 setup_comp.py [json]")
        sys.exit(1)
    
    setup_comp(sys.argv[1])

if __name__ == '__main__':
    main()