#!/bin/bash

let 'n_h=6' 'n_r=6'

human_pos_list=(
    "20 0"
    "0 12"
    "0 13"
    "0 14"
    "0 15"
    "0 16"
    "0 17"
    "0 18"
    "0 19"
    "0 20"
    "-1 12"
    "-1 13"
    "-1 14"
    "-1 15"
    "-1 16"
    "-1 17"
    "-1 18"
    "-1 19"
    "-1 20"
    "-2 12"
    "-2 13"
    "-2 14"
    "-2 15"
    "-2 16"
    "-2 17"
    "-2 18"
    "-2 19"
    "-2 20"
)

robot_pos_list=(
    "0 0"
    "10 0"
    "0 10"
    "1 0"
    "2 0"
    "3 0"
    "4 0"
    "5 0"
    "6 0"
    "7 0"
    "8 0"
    "9 0"
    "0 1"
    "0 2"
    "0 3"
    "0 4"
    "0 5"
    "0 6"
    "0 7"
    "0 8"
    "0 9"
)

function new_windows_run_command() {
    echo "$1"
    window_name="$1"
    shift 1
    tmux new-window -n "${window_name}" \; \
        send-keys "docker exec -it sim bash src/t_all_x.sh $*" C-m \;
}

function kill_sa() {
    # kill HRI components, HRI Engine, service application
    tmux send-keys -t "run SA" C-c
    tmux send-keys -t "run HRI engines" C-c
    tmux send-keys -t "setup components" C-c
}

function kill_nav() {
    # spawn humans-nav
    for ((i=0;i<n_h;i++)); do
        tmux send-keys -t "spawn human$((i+1))-nav" C-c
    done

    # spawn robots-nav
    for ((i=0;i<n_r;i++)); do
        robot_name="robot$((i+1))"
        tmux send-keys -t "spawn ${robot_name}-nav" C-c
    done
}

function start_nav() {
    # spawn humans-nav
    for ((i=0;i<n_h;i++)); do
        new_windows_run_command "spawn human$((i+1))-nav" "t2_x_n" "human$((i+1))" "${human_pos_list[i]}"
    done

    # spawn robots-nav
    for ((i=0;i<n_r;i++)); do
        robot_name="robot$((i+1))"
        new_windows_run_command "spawn ${robot_name}-nav" "t2_x_n" "robot$((i+1))" "${robot_pos_list[i]}"
    done
}

function start_sa() {
    # setup HRI components, HRI Engine, service application
    # spawn robots
    model_name=()
    for ((i=0;i<N_r;i++)); do
        robot_name="robot$((i+1))"
        model_name+=("${robot_name}")
    done
    new_windows_run_command "setup components" "t3m" "${model_name[*]}"
    new_windows_run_command "run HRI engines" "t4m"
    new_windows_run_command "run SA" "t5"

    # operate human1
    new_windows_run_command "operate human to walk" "t5a"
}

function start_sa2() {
    # setup HRI components, HRI Engine, service application
    # spawn robots
    model_name=()
    for ((i=0;i<N_r;i++)); do
        robot_name="robot$((i+1))"
        model_name+=("${robot_name}")
    done
    new_windows_run_command "setup engines and components" "t34m" "${model_name[*]}"
    new_windows_run_command "run SA" "t5"

    # operate human1
    new_windows_run_command "operate human to walk" "t5a"
}

case $1 in
    "restart" )
        kill_sa
        kill_nav
        docker exec -it sim bash src/t_all_x.sh reset
        start_nav
        start_sa
        ;;
    "reset" )
        docker exec -it sim bash src/t_all_x.sh reset
        ;;
    "kill_sa" )
        kill_sa
        ;;
    "sa" )
        start_sa
        ;;
    "nav" )
        start_nav
        ;;    
    "kill_nav" )
        kill_nav
        ;;    
    * )
        echo "launch gazebo"
        tmux new-session -d \; \
            send-keys "bash run_docker_im_x.sh" C-m \;

        sleep 5
        # pause gazebo
        new_windows_run_command "pause gazebo" "g_pause"

        # spawn humans
        for ((i=0;i<n_h;i++)); do
            new_windows_run_command "spawn human$((i+1))" "t2_x_h" "human$((i+1))" "${human_pos_list[i]}"
        done

        # spawn robots
        for ((i=0;i<n_r;i++)); do
            robot_name="robot$((i+1))"
            new_windows_run_command "spawn ${robot_name}" "t2_x_r" "robot$((i+1))" "${robot_pos_list[i]}"
        done

        # start_sa

        echo "finish script"

        tmux a
        ;;
esac