#! /bin/bash

source devel/setup.bash

function wait_roscore() {
    wait-for-it localhost:11311 -- echo "ready"
}

function wait_gazebo() {
    wait_roscore
    while [ -z `rostopic list|grep /gazebo/model_states` ]
    do 
        echo "waiting gazebo"
        sleep 1
    done 
}

function wait_robot() {
    wait_gazebo
    for x in $@; do
        while [ -z `rosnode list|grep $x/move_base` ]
        do 
            echo "waiting $x"
            sleep 1
        done 
    done 
}


case $1 in
    "t2" )
        wait_roscore
        roslaunch rois_gazebo spawn_human.launch
        ;;
    "t2_x_h" )
        # spawn human
        wait_gazebo
        roslaunch rois_gazebo spawn_human_x.launch "model_name:=$2" "init_x:=$3" "init_y:=$4"
        ;;
    "t2_x_r" )
        # spawn robot
        wait_gazebo
        roslaunch rois_gazebo spawn_robot_x.launch "model_name:=$2" "init_x:=$3" "init_y:=$4"
        ;;
    "t2_x_m" )
        # spawn model
        wait_gazebo
        roslaunch rois_gazebo spawn_model_x.launch "model_name:=$2" "init_x:=$3" "init_y:=$4"
        ;;
    "t2_x_n" )
        wait_gazebo
        roslaunch rois_gazebo spawn_nav.launch "model_name:=$2" "init_x:=$3" "init_y:=$4"
        ;;
    "t3" )
        wait_roscore
        while [ -z `rostopic list|grep /human1` ]
        do 
            echo "waiting human1"
            sleep 1
        done 
        roscd route_guidance_ros/scripts/
        python3 -c "import setup_comp_servers;setup_comp_servers.setup_single_robot();input('hit Enter key')"
        ;;
    "t3m" )
        # setup HRI components
        shift 1
        wait_robot "$*"
        rosservice call gazebo/unpause_physics
        roscd route_guidance_ros/scripts/
        python3 -c "import setup_comp_servers;setup_comp_servers.setup_multi_robot();input('hit Enter key')"
        ;;
    "t34m" )
        # setup HRI components
        shift 1
        wait_robot "$*"
        rosservice call gazebo/unpause_physics
        roscd route_guidance_ros/scripts/
        python3 setup_eng_comp.py ../../ep1 ../../cl1 8000
        ;;
    "t4" )
        wait_roscore
        roscd route_guidance_ros/scripts/
        python3 setup_engines.py
        ;;
    "t4m" )
        # setup HRI Engine
        wait_roscore
        roscd route_guidance_ros/scripts/
        python3 wait_server.py client_info_2.json comp
        python3 setup_engines_multi.py
        ;;
    "t5" )
        # setup service application
        wait_roscore
        roscd route_guidance_ros/scripts/
        python3 wait_server.py client_info_2.json comp
        python3 wait_server.py client_info_2.json eng
        wait-for-it localhost:8000 -- echo "ready main HRI Engine"
        python3 sa_multi.py
        ;;
    "t5x" )
        # setup service application
        wait_roscore
        roscd route_guidance_ros/scripts/
        wait-for-it localhost:8000 -- echo "ready main HRI Engine"
        python3 sa_multi.py
        ;;
    "t5a" )
        # operate human1
        wait-for-it localhost:8000 -- echo "ready"
        sleep 5
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[0,0,0]" "[0,0,-1]"
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[1,0,0]" "[0,0,0]"
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[1,0,0]" "[0,0,0]"
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[0,0,0]" "[0,0,-1]"
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[1,0,0]" "[0,0,0]"
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[1,0,0]" "[0,0,0]"
        rostopic pub -1 human1/diff_drive_controller/cmd_vel geometry_msgs/Twist -- "[0,0,0]" "[0,0,0]"
        ;;
    "t5o" )
        rostopic pub -1 robot1/detected_text std_msgs/String "data: 'point_a'"
        ;;

    "g_pause" )
        wait_gazebo
        rosservice call gazebo/pause_physics
        ;;
    "g_unpause" )
        wait_gazebo
        rosservice call gazebo/unpause_physics
        ;;
    "reset" )
        rosservice call gazebo/pause_physics
        rosservice call gazebo/reset_simulation
        rosservice call gazebo/set_model_state "model_state:
  model_name: 'c_corridor'
  pose:
    position:
      x: 12.1026
      y: 9.54724
      z: 0.0
    orientation:
      x: 0.0
      y: 0.0
      z: 0.0
      w: 1.0
  twist:
    linear:
      x: 0.0
      y: 0.0
      z: 0.0
    angular:
      x: 0.0
      y: 0.0
      z: 0.0
  reference_frame: ''" 
        rosservice call gazebo/unpause_physics
        ;;

esac